@@ -1,12 +1,10 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2003
- * http://soul.datamax.bg/~cade  <cade@biscom.net>  <cade@datamax.bg>
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfu.cpp,v 1.53 2007/12/16 13:52:50 cade Exp $
- *
  */
 
 #include "vfu.h"
@@ -131,7 +129,7 @@ void say( int line, int attr, const char* format, ... )
   say_str = str_dot_reduce( say_buf, con_max_x()-1 );
   con_out( 1, con_max_y() - ( (line == 1) ? 1 : 0 ), say_str, attr );
   con_ce( attr );
-};
+}
 
 void say1(const char *a_str, int attr )
 {
@@ -161,7 +159,7 @@ void saycenter( int line, int attr, const char *a_str )
     str = str + a_str;
     }
   say( line, attr, "%s", str.data() );
-};
+}
 
 void say1center(const char *a_str, int attr )
 {
@@ -188,14 +186,14 @@ void TF::reset() /* reset -- NULL all fields */
   _view = NULL;
   _color = cPLAIN;
   sel = 0;
-};
+}
 
 /*-----------------------------------------------------------------------*/
 
 TF::TF()
 {
   reset();
-};
+}
 
 /*-----------------------------------------------------------------------*/
 
@@ -204,7 +202,7 @@ TF::TF( const char* a_name, const struct stat* a_stat, int a_is_link )
   reset();
   set_name( a_name );
   update_stat( a_stat, a_is_link );
-};
+}
 
 /*-----------------------------------------------------------------------*/
 
@@ -213,7 +211,7 @@ TF::~TF()
   if ( _name ) delete [] _name;
   if ( _view ) delete [] _view;
   reset();
-};
+}
 
 /*-----------------------------------------------------------------------*/
 
@@ -236,7 +234,7 @@ const char* TF::full_name( int fix )
   if ( fix && _is_dir )
     strcat( _full_name, "/" ); /* i.e. str_fix_path() */
   return _full_name;
-};
+}
 
 /*-----------------------------------------------------------------------*/
 
@@ -262,7 +260,7 @@ void TF::set_name( const char* a_new_name )
   _color = get_item_color( this ); /* this is duplicated here and in update_stat() */
 
   drop_view();
-};
+}
 
 /*-----------------------------------------------------------------------*/
 
@@ -413,7 +411,7 @@ void TF::update_stat( const struct stat* a_new_stat, int a_is_link )
   _color = get_item_color( this );
 
   drop_view();
-};
+}
 
 /*######################################################################*/
 
@@ -490,7 +488,7 @@ void vfu_help()
   vfu_menu_box( 1, 4, "VFU Help ( PageUp/PageDown to scroll )" );
   mb.undef();
   do_draw = 1;
-};
+}
 
 /*--------------------------------------------------------------------------*/
 
@@ -945,16 +943,15 @@ void vfu_run()
       case 'j'        : vfu_jump_to_mountpoint( 0 ); break;
       case KEY_ALT_J  : vfu_jump_to_mountpoint( 1 ); break;
 
-      case KEY_ALT_0  : bookmark_goto( 0 ); break;
-      case KEY_ALT_1  : bookmark_goto( 1 ); break;
-      case KEY_ALT_2  : bookmark_goto( 2 ); break;
-      case KEY_ALT_3  : bookmark_goto( 3 ); break;
-      case KEY_ALT_4  : bookmark_goto( 4 ); break;
-      case KEY_ALT_5  : bookmark_goto( 5 ); break;
-      case KEY_ALT_6  : bookmark_goto( 6 ); break;
-      case KEY_ALT_7  : bookmark_goto( 7 ); break;
-      case KEY_ALT_8  : bookmark_goto( 8 ); break;
-      case KEY_ALT_9  : bookmark_goto( 9 ); break;
+      case KEY_ALT_1  : bookmark_goto( '1' ); break;
+      case KEY_ALT_2  : bookmark_goto( '2' ); break;
+      case KEY_ALT_3  : bookmark_goto( '3' ); break;
+      case KEY_ALT_4  : bookmark_goto( '4' ); break;
+      case KEY_ALT_5  : bookmark_goto( '5' ); break;
+      case KEY_ALT_6  : bookmark_goto( '6' ); break;
+      case KEY_ALT_7  : bookmark_goto( '7' ); break;
+      case KEY_ALT_8  : bookmark_goto( '8' ); break;
+      case KEY_ALT_9  : bookmark_goto( '9' ); break;
       case '`'        : bookmark_goto(-1 ); break;
 
       case 9          : vfu_edit_entry(); break;
@@ -1084,7 +1081,7 @@ void vfu_signal( int sig )
 
   printf( "vfu: signal received: %d -- terminated\n", sig );
   exit(200);
-};
+}
 
 /*--------------------------------------------------------------------------*/
 
@@ -1113,7 +1110,7 @@ void vfu_toggle_view_fields( int ch )
     default  : return; /* cannot be reached really */
     }
   vfu_drop_all_views();
-};
+}
 
 /*--------------------------------------------------------------------------*/
 
@@ -1220,7 +1217,7 @@ void vfu_edit( const char *fname )
     {
     say1( "Cannot edit directory");
     return;
-    };
+    }
   con_cs();
   if ( opt.internal_editor )
     {
@@ -1395,7 +1392,7 @@ void vfu_action_plus( int key )
       { /* file */
       vfu_browse_archive_file();
       }
-    };
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1621,7 +1618,7 @@ void vfu_global_select()
       {
       say1( "GlobalSelect/Extended not available in this mode." );
       return;
-      };
+      }
     mb.undef();
     mb.push( "A Select to begin" );
     mb.push( "E Select to end" );
@@ -1647,22 +1644,22 @@ void vfu_global_select()
                for (int z = 0; z < files_count; z++)
                  if (!files_list[z]->is_dir())
                    files_list[z]->sel = 1;
-               }; break;
+               } break;
     case 'A' : {
                for (int z = 0; z < files_count; z++)
                  files_list[z]->sel = 1;
-               }; break;
+               } break;
     case 'R' : {
                int z;
                for (z = 0; z < files_count; z++)
                  if (!files_list[z]->is_dir())
                    files_list[z]->sel = !files_list[z]->sel;
-               }; break;
+               } break;
     case 'C' : {
                int z;
                for (z = 0; z < files_count; z++)
                    files_list[z]->sel = 0;
-               }; break;
+               } break;
     case 'P' :
                {
                int z;
@@ -1675,7 +1672,7 @@ void vfu_global_select()
                    }
                  }
                vfu_pack_files_list();
-               }; break;
+               } break;
     case 'H' :
                {
                int z;
@@ -1688,7 +1685,7 @@ void vfu_global_select()
                    }
                  }
                vfu_pack_files_list();
-               }; break;
+               } break;
     case '.' :
                {
                int z;
@@ -1701,7 +1698,7 @@ void vfu_global_select()
                    }
                  }
                vfu_pack_files_list();
-               }; break;
+               } break;
     case ',' :
                {
                int z;
@@ -1714,7 +1711,7 @@ void vfu_global_select()
                    }
                  }
                vfu_pack_files_list();
-               }; break;
+               } break;
     case '+' :
     case '=' :
     case '-' :
@@ -1748,14 +1745,14 @@ void vfu_global_select()
                 }
               say1( " " );
               say2( " " );
-              }; break;
+              } break;
     case 'D' :
               {
               if ( work_mode != WM_NORMAL )
                 {
                 say1( "GlobalSelect/Different not available in this mode." );
                 break;
-                };
+                }
               VString target;
               if ( vfu_get_dir_name( "Target directory:", target ))
                 {
@@ -1772,7 +1769,7 @@ void vfu_global_select()
                 }
               say1( "Done." );
               say2( " " );
-              }; break;
+              } break;
     case '/':
     case '\\':
     case 'E':
@@ -1860,7 +1857,7 @@ void vfu_global_select()
                 case 'A' : vfu_global_select_same( GSAME_MODE  ); break;
                 case 'Y' : vfu_global_select_same( GSAME_TYPE  ); break;
                 }
-              }; break;
+              } break;
     case 'M': {
               mode_str_t mode_str;
               strcpy( mode_str, MODE_STRING );
@@ -1871,19 +1868,19 @@ void vfu_global_select()
                      (strcmp( files_list[z]->mode_str()+1, mode_str+1 ) == 0);
                 do_draw = 1;
                 }
-              }; break;
+              } break;
     case '<' : {
                if( files_count > 0)
                  for (int z = 0; z <= FLI; z++)
                    if (!files_list[z]->is_dir())
                      files_list[z]->sel = 1;
-               }; break;
+               } break;
     case '>' : {
                if( files_count > 0)
                  for (int z = FLI; z < files_count; z++)
                    if (!files_list[z]->is_dir())
                      files_list[z]->sel = 1;
-               }; break;
+               } break;
     }
   update_status();
   do_draw = 1;
@@ -1922,7 +1919,7 @@ int vfu_user_external_find( int key, const char* ext, const char* type, VString
     return z;
     }
   return -1;
-};
+}
 
 /*--------------------------------------------------------------------------*/
 
@@ -2041,30 +2038,40 @@ void bookmark_goto( int n )
     mb.push( "---" );
     for( z = 1; z < 10; z++ )
       {
-      const char* ps = path_bookmarks.get( z );
+      const char* ps = path_bookmarks.get( z-1 );
       if( !ps ) break;
       sprintf(t, "%d %s", z%10, ps );
       mb.push( str_dot_reduce( t, 60 ) );
       }
     n = vfu_menu_box( 5, 5, "Path bookmarks");
     if ( n == -1 ) return;
-    n++;
+    n = menu_box_info.ec;
     }
   // FIXME: neshto ne raboti :/
-  switch( menu_box_info.ec )
+  switch( n )
     {
     case '`' : vfu_chdir( NULL ); return;
     case 'A' : bookmark_hookup(); return;
     }
-  if ( n >= '0' && n <= '9' && str_len( path_bookmarks[n - '0'] ) > 0 )
+  if ( n >= '1' && n <= '9' && str_len( path_bookmarks[ n - '1' ] ) > 0 )
     {
-    vfu_chdir( path_bookmarks[n - '0'] );
+    vfu_chdir( path_bookmarks[ n - '1' ] );
     return;
     }
 }
 
 void bookmark_hookup()
 {
+  int found = -1;
+  for( int z = 0; z < path_bookmarks.count(); z++ )
+    {
+    if( work_path == path_bookmarks[z] ) found = z;
+    }
+  if( found > -1 )
+    {
+    say1( "Current directory is already hooked", chRED );
+    return;
+    }
   path_bookmarks.push( work_path );
   if ( path_bookmarks.count() > 10 )
     path_bookmarks.shift();
@@ -2600,7 +2607,7 @@ void vfu_user_menu()
     VString str = lines[z];
     vfu_user_external_archive_exec( str );
     }
-};
+}
 
 /*--------------------------------------------------------------------------*/
 
@@ -2655,7 +2662,7 @@ void vfu_file_find_results()
 
   file_find_results.fsave( filename_ffr );
   con_cs();
-};
+}
 
 /*--------------------------------------------------------------------------*/
 
@@ -2690,7 +2697,7 @@ int __ff_process( const char* origin,    /* origin path */
   int add = 0;
   int z;
   for ( z = 0; z < __ff_masks.count(); z++ )
-    if ( FNMATCH( __ff_masks[z], pc ) == 0 )
+    if ( opt.no_case_glob ? FNMATCH_NC( __ff_masks[z], pc ) == 0 : FNMATCH( __ff_masks[z], pc ) == 0 )
       {
       add = 1;
       break;
@@ -2790,7 +2797,7 @@ void vfu_file_find( int menu )
   file_find_results.undef();
   ftwalk( __ff_path, __ff_process );
   vfu_file_find_results();
-};
+}
 
 /*--------------------------------------------------------------------------*/
 
@@ -2819,7 +2826,7 @@ void vfu_read_files_menu()
       str_set_ch( t, 0, toupper(str_get_ch(t, 0)) );
       mb.push(t);
       list.push(str);
-      };
+      }
     }
   z = vfu_menu_box( 25, 5, "Read/Rescan Files" );
   if ( z == -1 )
@@ -2841,7 +2848,7 @@ void vfu_read_files_menu()
     case 'R' : vfu_read_files( 1 ); break;
     case 'L' : con_cs(); vfu_drop_all_views(); do_draw = 2; break;
     }
-};
+}
 
 /*--------------------------------------------------------------------------*/
 
@@ -2887,7 +2894,10 @@ void vfu_inc_search()
       if( s_size )
         found = files_list[z]->size() == s_size;
       else
-        found = ( FNMATCH( s_mask, files_list[z]->name_ext() ) == 0 );
+        if( opt.no_case_glob )
+          found = ( FNMATCH_NC( s_mask, files_list[z]->name_ext() ) == 0 );
+        else
+          found = ( FNMATCH( s_mask, files_list[z]->name_ext() ) == 0 );
       if ( found ) break;
       z += direction;
       if ( loops++ > files_count ) break;
