@@ -1,7 +1,7 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2000
- * http://www.biscom.net/~cade  <cade@biscom.net>  <cade@datamax.bg>
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
@@ -15,7 +15,7 @@
   void vfu_read_archive_files();
   void vfu_browse_archive_file();
   void vfu_extract_files( int one );
-  void vfu_user_external_archive_exec( String &shell_line  );
+  void vfu_user_external_archive_exec( VString &shell_line  );
 
 #endif /* _VFUARC_H_ */
 
