@@ -1,12 +1,10 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2003
- * http://soul.datamax.bg/~cade  <cade@biscom.net>  <cade@datamax.bg>
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfudir.cpp,v 1.30 2007/12/16 13:44:10 cade Exp $
- *
  */
 
 #include "vfudir.h"
@@ -40,7 +38,12 @@ VArray size_cache;
         {
         if ( strcmp( de->d_name, "." ) == 0 ||
              strcmp( de->d_name, ".." ) == 0 ) continue;
-        if ( a_fnpattern[0] == 0 || FNMATCH( pat, de->d_name)==0 )
+        int match_ok = 0;
+        if( opt.no_case_glob )
+          match_ok = FNMATCH_NC( pat, de->d_name) == 0;
+        else
+          match_ok = FNMATCH( pat, de->d_name) == 0;
+        if ( a_fnpattern[0] == 0 || match_ok )
           {
           VString str; // = a_path;
           str += de->d_name;
@@ -164,23 +167,38 @@ int vfu_get_dir_name( const char *prompt, VString &target, int should_exist )
         {
         if ( dir_list.count() > 1)
           {
+          int li; /* counter */
+          int xm = 0; /* exact match entry  */
+          for ( li = 0; li < dir_list.count(); li++ )
+            {
+            VString tmp1;
+            if( dtail != str_copy( tmp1, dir_list[li], 0, str_len( dtail ) ) )
+              continue;
+            xm = li;
+            break;
+            }
           int mc = 0; /* match count        */
           int mi = 0; /* match letter index */
           while(4)
             {
             mc = 0;
-            int li; /* counter */
             for ( li = 0; li < dir_list.count(); li++ )
               {
-              if ( str_get_ch( dir_list[ 0], mi ) ==
-                   str_get_ch( dir_list[li], mi ) )
+              char ch1 = str_get_ch( dir_list[xm], mi );
+              char ch2 = str_get_ch( dir_list[li], mi );
+              if( opt.no_case_glob )
+                {
+                ch1 = toupper( ch1 );
+                ch2 = toupper( ch2 );
+                }
+              if ( ch1 == ch2 )
                 mc++;
               }
             if ( mc != dir_list.count() )
               break;
             mi++;
             }
-          target.setn( dmain + dir_list[0], str_len( dmain ) + mi );
+          target.setn( dmain + dir_list[xm], str_len( dmain ) + mi );
           pos = str_len( target );
           say2( target, cINPUT );
           con_xy( pos+1, con_max_y() );
@@ -273,7 +291,7 @@ int vfu_get_dir_name( const char *prompt, VString &target, int should_exist )
       {
       con_chide();
       int zz = vfu_hist_menu( 5, 5, ( ch == KEY_PPAGE ) ? "Dir Entry History" : "ChDir History",
-                              ( ch == KEY_PPAGE ) ? HID_GETDIR : HID_CHDIR );
+                                    ( ch == KEY_PPAGE ) ? HID_GETDIR : HID_CHDIR );
       con_cshow();
       if (zz != -1)
         {
