@@ -1,12 +1,10 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2003
- * http://soul.datamax.bg/~cade  <cade@biscom.net>  <cade@datamax.bg>
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfuopt.cpp,v 1.18 2008/01/18 18:40:30 cade Exp $
- *
  */
 
 #include "vfu.h"
@@ -59,6 +57,7 @@ ToggleEntry Toggles[] =
   { ' ', "Use CWD as target for COPY/MOVE", &(opt.default_copy_to_cwd), NOYES },
   {  0 , "--other--", NULL, NULL },
 /*  { ' ', "Can Zap/Erase READ-ONLY Files?!",       &(opt.zap_ro), NOYES }, ? */
+  { ' ', "Case insensitive file/dir names matching",       &(opt.no_case_glob), NOYES },
   { 'b', "Allow beep!",       &(opt.allow_beep), NOYES },
   { 's', "Free space check on copy",  &(opt.copy_free_space_check), NOYES },
   { ' ', "Auto mount on change dir",  &(opt.auto_mount), NOYES},
@@ -78,12 +77,12 @@ time_t vfu_opt_time( const struct stat st )
   if (opt.f_time_type == 1) return st.st_mtime; else
   if (opt.f_time_type == 2) return st.st_atime; else
   return 0;
-};
+}
 
 time_t vfu_opt_time( const struct stat* st )
 {
   return vfu_opt_time( *st );
-};
+}
 
 time_t vfu_opt_time( time_t ctime, time_t mtime, time_t atime )
 {
@@ -151,7 +150,7 @@ void vfu_load_dir_colors()
       }
 
   #endif /* _TARGET_UNIX_ */
-};
+}
 
 /*---------------------------------------------------------------------------*/
 
@@ -223,7 +222,7 @@ int key_by_name( const char* key_name )
       return KEY_SH_F1 + atoi( key_name + 2 ) - 1;
     }
   return 0;
-};
+}
 
 /*---------------------------------------------------------------------------*/
 
@@ -236,6 +235,7 @@ void vfu_settings_load()
   see_filters.undef();
   panelizers.undef();
   archive_extensions.undef();
+  path_bookmarks.undef();
 
   /***** LOAD DEFAULTS *******/
 
@@ -352,6 +352,7 @@ void vfu_settings_load()
 
       if(set_arr( line, "bookmark",  path_bookmarks))continue;
       // follow 10 are deprecated
+      /*
       if(set_arr( line, "bookmark1", path_bookmarks))continue;
       if(set_arr( line, "bookmark2", path_bookmarks))continue;
       if(set_arr( line, "bookmark3", path_bookmarks))continue;
@@ -361,6 +362,7 @@ void vfu_settings_load()
       if(set_arr( line, "bookmark7", path_bookmarks))continue;
       if(set_arr( line, "bookmark8", path_bookmarks))continue;
       if(set_arr( line, "bookmark9", path_bookmarks))continue;
+      */
 
    /* if(set_str( line, "cblack"   , ext_colors[0]); */
       if(set_str( line, "cgreen"   , ext_colors[cGREEN]))continue;
@@ -481,5 +483,5 @@ void vfu_options()
   vfu_redraw_status();
   say1("");
   say2("");
-};
+}
 
