@@ -1,12 +1,10 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2003
- * http://soul.datamax.bg/~cade  <cade@biscom.net>  <cade@datamax.bg>
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfuopt.h,v 1.9 2005/06/07 22:33:48 cade Exp $
- *
  */
 
 #ifndef _VFUOPT_H_
@@ -62,6 +60,8 @@
 
     int zap_ro; /* zap/erase read-only files */
 
+    int no_case_glob;
+
     int show_user_free; /* ...space instead of real fs free */
     int menu_borders;
 
