@@ -1,12 +1,10 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2003
- * http://soul.datamax.bg/~cade  <cade@biscom.net>  <cade@datamax.bg>
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfuuti.cpp,v 1.19 2007/12/16 13:52:50 cade Exp $
- *
  */
 
 #include "vfu.h"
@@ -298,7 +296,8 @@ void vfu_beep()
 
 /*###########################################################################*/
 
-#define MAXHIST         14      // max history items per id
+static char hist_menu_hotkeys[] = "1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+#define MAXHIST         128      // max history items per id
 #define HISTIDPAD       8
 
 void vfu_hist_add( int hist_id, const char* str )
@@ -318,7 +317,7 @@ void vfu_hist_add( int hist_id, const char* str )
     }
   if (z) z++;
   history.ins( 0, hstr );
-};
+}
 
 const char* vfu_hist_get( int hist_id, int index )
 {
@@ -335,7 +334,7 @@ const char* vfu_hist_get( int hist_id, int index )
       i++;
       }
   return NULL;
-};
+}
 
 char* vfu_hist_get( int hist_id, int index, char* str )
 {
@@ -343,7 +342,7 @@ char* vfu_hist_get( int hist_id, int index, char* str )
   const char* pstr = vfu_hist_get( hist_id, index );
   if ( pstr ) strcpy( str, pstr );
   return str;
-};
+}
 
 int vfu_hist_index( int hist_id, const char* value )
 {
@@ -353,7 +352,7 @@ int vfu_hist_index( int hist_id, const char* value )
     if ( strcmp( value, vfu_hist_get( hist_id, z ) ) == 0 )
       return z;
   return -1;
-};
+}
 
 int vfu_hist_count( int hist_id )
 {
@@ -365,7 +364,7 @@ int vfu_hist_count( int hist_id )
   for ( z = 0; z < history.count(); z++ )
     cnt += ( strncmp( hstr, history[z], HISTIDPAD+1 ) == 0 );
   return cnt;
-};
+}
 
 // use hist_id=-1 and/or index=-1 to remove all
 void vfu_hist_remove( int hist_id, int index )
@@ -381,10 +380,9 @@ void vfu_hist_remove( int hist_id, int index )
     if ( index != -1 && index != i ) { z++; i++; continue; }
     history.del( z );
     if ( index != -1 ) break;
-    };
-};
+    }
+}
 
-static char hist_menu_hotkeys[] = "1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZ";
 int vfu_hist_menu( int x, int y, const char* title, int hist_id )
 {
   VString str;
@@ -393,16 +391,17 @@ int vfu_hist_menu( int x, int y, const char* title, int hist_id )
   int z;
   int cnt = vfu_hist_count( hist_id );
   if ( cnt < 1 ) return -1;
+  if ( cnt > con_max_y() - 9 ) cnt = con_max_y() - 9; // limit to visible space
   for ( z = 0; z < cnt; z++ )
     {
-    ASSERT( z < str_len( hist_menu_hotkeys ) );
+//    ASSERT( z < str_len( hist_menu_hotkeys ) );
     str = "";
-    str_add_ch( str, hist_menu_hotkeys[z] );
+    str_add_ch( str, z < str_len( hist_menu_hotkeys ) ? hist_menu_hotkeys[z] : ' ' );
     str = str + " " + vfu_hist_get( hist_id, z );
     mb.push( str );
     }
   return vfu_menu_box( x, y, title );
-};
+}
 
 /*---------------------------------------------------------------------------*/
 
@@ -446,7 +445,7 @@ int vfu_get_str( const char *prompt, VString& target, int hist_id, int x, int y
   if( r )
     vfu_hist_add( hist_id, target );
   return ( r != 0 );
-};
+}
 
 /*---------------------------------------------------------------------------*/
 
@@ -459,7 +458,7 @@ const char* vfu_temp()
     mkstemp( vfu_temp_filename );
     unlink( vfu_temp_filename );
     return vfu_temp_filename;
-};
+}
 
 /*###########################################################################*/
 
