@@ -1,12 +1,10 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2003
- * http://soul.datamax.bg/~cade  <cade@biscom.net>  <cade@datamax.bg>
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfuview.cpp,v 1.17 2005/06/01 23:13:08 cade Exp $
- *
  */
 
 #include "vfu.h"
@@ -22,13 +20,27 @@ int tag_mark_pos;
 int get_item_color( TF *fi )
 {
   VString str;
+  int z;
 
   ASSERT( fi );
 
   if (!opt.use_colors)
     return cNORMAL; /* don't use colors -- option */
 
-  if ( fi->is_dir() ) return cCYAN; // dirs are cCYAN by default
+  /* try to find file type color first */
+
+  str = fi->type_str();
+  str = "." + str + ".";
+
+  if ( str != ".." )
+    {
+    for ( z = cBLACK; z <= chWHITE; z++ )
+      if (str_find( ext_colors[z], str ) != -1)
+        return z;
+    }
+
+
+  /* regular file, try to find extension color */
 
   str = fi->name();
   if ( str_get_ch( str, 0 ) == '.' )
@@ -47,18 +59,6 @@ int get_item_color( TF *fi )
   str_low( str );
   #endif
 
-  int z;
-  if ( str != ".." )
-    {
-    for ( z = cBLACK; z <= chWHITE; z++ )
-      if (str_find( ext_colors[z], str ) != -1)
-        return z;
-    }
-
-  /* extension not found -- try type string */
-  str = fi->type_str();
-  str = "." + str + ".";
-
   if ( str != ".." )
     {
     for ( z = cBLACK; z <= chWHITE; z++ )
@@ -131,6 +131,11 @@ void vfu_draw( int n )
     c += cBOLD;
     /* this is a hack, can be removed w/o warning :) -- more visibility */
     if ( c == 120 ) c = cTAG; // 116; // 123; // 63; // 123
+    //str_replace( view, " ", "_" );
+    //c += A_UNDERLINE;
+    //c += A_STANDOUT;
+    //str_replace( view, " ", "-" );
+    //c = CONCOLOR(cWHITE,cBLUE);
     }
   con_out( 1, n - FLP + 4, view, c );
   //  con_ce( c );
