@@ -1,6 +1,7 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-1999
+ * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
@@ -9,14 +10,10 @@
 #ifndef _VLIB_H_
 #define _VLIB_H_
 
-#include <target.h> // this must set _TARGET_XXX_ define
-
-#include <clusters.h>
 #include <vstring.h>
 #include <vstrlib.h>
 #include <fnmatch2.h>
 #include <getopt2.h>
-#include <regexp2.h>
 #include <vsuti.h>
 #include <dlog.h>
 #include <unicon.h>
@@ -24,6 +21,8 @@
 #include <form_in.h>
 #include <conmenu.h>
 
+#include "target.h"
+
 #endif //_VLIB_H_
 
  // eof vlib.h
