@@ -1,13 +1,12 @@
 /*
  *
  *  VSTRING Library
- * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-2003
+ *  (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ *  http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *  Distributed under the GPL license, you should receive copy of GPL!
  *
  *  SEE vstring.h FOR FURTHER INFORMATION AND CREDITS
  *
- *  $Id: vstring.cpp,v 1.26 2008/01/18 18:40:46 cade Exp $
- *
  *  This file (vstring.h and vstring.cpp) implements plain string-only
  *  manipulations. For further functionality see vstrlib.h and vstrlib.cpp.
  *
@@ -120,8 +119,6 @@
   {
     char tmp[64];
     sprintf( tmp, "%.0f", d );
-    int z = strlen( tmp );
-    tmp[z] = 0;
     set( tmp );
   }
 
@@ -466,7 +463,7 @@
 **
 ****************************************************************************/
 
-  char* str_mul( char* target, int n ) // multiplies the VString n times, i.e. `1'*5 = `11111'
+  char* str_mul( char* target, int n ) // multiplies the string n times, i.e. `1'*5 = `11111'
   {
     if ( n < 0 ) return target;
     if ( n == 0 )
@@ -528,14 +525,13 @@
     return -1;
   }
 
-
   char* str_del( char* target, int pos, int len ) // deletes `len' chars starting from `pos'
   {
     int sl = strlen( target );
     if ( pos > sl || pos < 0 ) return target;
-    int z = sl-pos-len;
+    int z = sl - pos - len;
     if ( pos + len < sl )
-      strncpy(target+pos, target+pos+len, z+1);
+      memmove( target + pos, target + pos + len, z + 1 );
     else
       target[pos] = 0;
     return target;
@@ -548,15 +544,9 @@
     int sls = strlen( s );
     if ( sls < 1 ) return target;
 
-    int z = sl - pos;
-    target[pos + z + sls] = 0;
-    while(z)
-      {
-      target[pos + z + sls - 1] = target[pos + z - 1];
-      z--;
-      }
+    memmove( target + pos + sls, target + pos, sl - pos + 1 );
+    memmove( target + pos, s, sls );
 
-    for(z = 0; z < sls; z++) target[pos+z] = s[z];
     return target;
   }
 
@@ -583,9 +573,20 @@
     return target;
   }
 
+  int   str_overlap( const char* target, const char* source, int len ) // check if source and target overlap, returns 1 if they do
+  {
+    int sl = len;
+    if( sl == -1 )
+      sl = strlen( source );
+
+    if ( target      >= source && target      <= source + sl ) return 1;
+    if ( target + sl >= source && target + sl <= source + sl ) return 1;
+    return 0;
+  }
 
   char* str_copy( char* target, const char* source, int pos, int len ) // returns `len' chars from `pos'
   {
+    ASSERT( len >= -1 );
     target[0] = 0;
     int sl = str_len( source );
     if ( pos < 0 )
@@ -594,11 +595,14 @@
       if ( pos < 0 ) pos = 0;
       }
     if ( pos < 0 || pos >= sl ) return target;
-    if ( len == -1 ) len = sl - pos;
+    if ( len == -1 ) len = sl - pos; // untill the end of the string (default arg)
     if ( len < 1 ) return target;
     if ( pos + len >= sl ) len = sl - pos;
 
-    strncpy( target, source + pos, len );
+    if( str_overlap( target, source + pos, len ) )
+      memmove( target, source + pos, len );
+    else
+      memcpy( target, source + pos, len );
     target[ len ] = 0;
     return target;
   }
@@ -610,21 +614,21 @@
 
   char* str_right( char* target, const char* source, int len ) // returns `len' chars from the right
   {
-    return str_copy( target, source, strlen(source) - len, len );
+    return str_copy( target, source, strlen( source ) - len, len );
   }
 
   char* str_sleft( char* target, int len ) // SelfLeft -- just as 'Left' but works on `this'
   {
-    if ( (size_t)len < strlen(target) ) target[len] = 0;
+    if ( (size_t)len < strlen(target) && (size_t)len >= 0 ) target[len] = 0;
     return target;
   }
 
   char* str_sright( char* target, int len ) // SelfRight -- just as 'Right' but works on `this'
   {
     int sl = strlen( target );
-    if ( len < sl )
+    if( len < sl )
       {
-      strcpy( target, target + ( sl - len ));
+      memmove( target, target + ( sl - len ), len + 1 );
       target[len] = 0;
       }
     return target;
@@ -632,9 +636,15 @@
 
   char* str_trim_left( char* target, int len ) // trims `len' chars from the beginning (left)
   {
-    int s = strlen( target ) - len;
-    if ( s > 0 )
-      strcpy( target, target + len );
+    int sl = strlen( target );
+    int sr = sl - len; // result string length (without trailing 0)
+    if( sr >= sl )
+      return target;
+    if( sr > 0 )
+      {
+      memmove( target, target + len, sr + 1 );
+      target[sr] = 0;
+      }
     else
       target[0] = 0;
     return target;
@@ -642,9 +652,12 @@
 
   char* str_trim_right( char* target, int len ) // trim `len' chars from the end (right)
   {
-    int e = strlen(target) - len;
-    if ( e > 0 )
-      target[e] = 0;
+    int sl = strlen( target );
+    int sr = sl - len; // result string length (without trailing 0)
+    if( sr >= sl )
+      return target;
+    if( sr > 0 )
+      target[sr] = 0;
     else
       target[0] = 0;
     return target;
@@ -678,16 +691,19 @@
 
 
   // return first `word', i.e. from pos 0 to first found delimiter char
-  // after that deletes this `word' from the VString
+  // after that deletes this `word' from the target
   char* str_word( char* target, const char* delimiters, char* result )
   {
     int z = 0;
     int sl = strlen( target );
     while ((strchr(delimiters, target[z]) == NULL) && (target[z] != 0)) z++;
-    strncpy(result, target, z);
+    memmove(result, target, z);
     result[z] = 0;
     if ( z > 0 )
-      strncpy( target, target + z + 1, sl - z + 1 );
+      if( z < sl )
+        memmove( target, target + z + 1, sl - z ); // including trailing zero
+      else
+        target[0] = 0;
     return result[0] ? result : NULL;
   }
 
@@ -699,7 +715,7 @@
     int z = sl - 1;
     while ( strchr( delimiters, target[z] ) == NULL && z > 0 ) z--;
     if (z < 0) return NULL;
-    strcpy( result, target + z + 1);
+    memmove( result, target + z + 1, sl - z );
     target[z] = 0;
     return result;
   }
@@ -707,11 +723,12 @@
 
   char* str_cut_left( char* target, const char* charlist ) // remove all chars `charlist' from the beginning (i.e. from the left)
   {
-    if (strlen(target) == 0) return target;
+    int sl = strlen(target);
+    if (sl == 0) return target;
     int z = 0;
     while ((strchr(charlist, target[z]) != NULL) && (target[z] != 0)) z++;
     if (z == 0) return target;
-    strcpy( target, target + z );
+    memmove( target, target + z, sl - z + 1 );
     return target;
   }
 
@@ -738,7 +755,8 @@
     return target;
   }
 
-  // expand align in a field, filled w. `ch', if len > 0 then right, else left
+  // expand string to width 'len' filling with char 'ch'
+  // if len > 0 target will be padded right, else left
   char* str_pad( char* target, int len, char ch )
   {
     int sl = strlen( target );
@@ -838,8 +856,8 @@
 
   char* str_squeeze( char* target, const char* sq_chars ) // squeeze repeating chars to one only
   {
-  if (!target) return NULL;
-  if (!sq_chars) return NULL;
+  if ( ! target   ) return NULL;
+  if ( ! sq_chars ) return NULL;
   int rc = -1;
   int pos = 0;
   while( target[pos] )
@@ -1722,13 +1740,13 @@ VString str_reduce_path( const char* path ) // removes ".."s
     int j = i - 1;
     while( j >= 0 && dest[j] != '/' ) j--;
     ASSERT( j >= -1 );
-	if ( j < 0 )
-	  {
-	  if ( dest[0] == '/' )
-	    str_del( dest, 0, 3 );
-	  }
-	else
-	  str_del( dest, j+1, i+3-j );
+  if ( j < 0 )
+    {
+    if ( dest[0] == '/' )
+      str_del( dest, 0, 3 );
+    }
+  else
+    str_del( dest, j+1, i+3-j );
     }
   return dest;
 }
@@ -1743,8 +1761,12 @@ VString str_reduce_path( const char* path ) // removes ".."s
   {
     long P = 1;
     long C = 0;
+
     char tmp[255];
-    strcpy( tmp, s ); str_up( tmp ); str_cut_spc( tmp );
+    strcpy( tmp, s );
+    str_up( tmp );
+    str_cut_spc( tmp );
+
     int sl = strlen(tmp);
     for( int z=sl-1; z >= 0; z-- )
       {
