@@ -1,7 +1,8 @@
 /*
  *
  *  VSTRING Library
- * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-2003
+ *  (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ *  http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *  Distributed under the GPL license, you should receive copy of GPL!
  *
  *  VSTRING library provides vast set of string manipulation features
@@ -18,9 +19,8 @@
  *  free to contact me at:
  *
  *  Vladi Belperchinov-Shabanski "Cade"
- *  <cade@biscom.net>
- *  <cade@datamax.bg>
- *  http://soul.datamax.bg/~cade
+ *  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
+ *  http://cade.datamax.bg/
  *
  *  NOTE: vstring was initially (and loosely) based on
  *        `cxstring' lib (c) Ivo Baylov 1998.
@@ -29,8 +29,6 @@
  *  This file (vstring.h and vstring.cpp) implements plain string-only
  *  manipulations. For further functionality see vstrlib.h and vstrlib.cpp.
  *
- *  $Id: vstring.h,v 1.24 2008/01/18 18:40:46 cade Exp $
- *
  */
 
 #ifndef _VSTRING_H_
@@ -239,6 +237,9 @@ public:
        { box->sl = strlen(box->s);
          box->resize_buf(box->sl);
          ASSERT( box->sl < box->size ); }
+  void fixbuf()
+       { box->resize_buf(box->sl);
+         ASSERT( box->sl < box->size ); }
 
   void   i( const int n );
   void   l( const long n );
@@ -271,7 +272,7 @@ public:
   friend VString& str_ins_ch ( VString& target, int pos, char ch ); // inserts `ch' in position `pos'
   friend VString& str_replace( VString& target, const char* out, const char* in ); // replace `out' w. `in'
 
-  friend VString& str_copy  ( VString& target, const char* source, int pos, int len = -1 ); // returns `len' chars from `pos'
+  friend VString& str_copy  ( VString& target, const char* source, int pos = 0, int len = -1 ); // returns `len' chars from `pos'
   friend VString& str_left  ( VString& target, const char* source, int len ); // returns `len' chars from the left
   friend VString& str_right ( VString& target, const char* source, int len ); // returns `len' chars from the right
   friend VString& str_sleft ( VString& target, int len ); // SelfLeft -- just as 'Left' but works on `this'
@@ -339,7 +340,9 @@ public:
   char* str_ins_ch ( char* target, int pos, char ch ); // inserts `ch' in position `pos'
   char* str_replace( char* target, const char* out, const char* in ); // replace `out' w. `in'
 
-  char* str_copy  ( char* target, const char* source, int pos, int len = -1 ); // returns `len' chars from `pos'
+  int   str_overlap( const char* target, const char* source, int len = -1 ); // check if source and target overlap, returns 1 if they do
+
+  char* str_copy  ( char* target, const char* source, int pos = 0, int len = -1 ); // returns `len' chars from `pos'
   char* str_left  ( char* target, const char* source, int len ); // returns `len' chars from the left
   char* str_right ( char* target, const char* source, int len ); // returns `len' chars from the right
   char* str_sleft ( char* target, int len ); // just as 'left' but works on `target'
